@@ -34,7 +34,9 @@ Python2Backend::Python2Backend(QObject* parent,const QList<QVariant> args ) : Ca
 {
     kDebug()<<"Creating Python2Backend";
 
+    new Python2LinearAlgebraExtension(this);
     new Python2PackagingExtension(this);
+    new Python2PlotExtension(this);
     new Python2ScriptExtension(this);
     new Python2VariableManagementExtension(this);
 
@@ -68,12 +70,6 @@ Cantor::Backend::Capabilities Python2Backend::capabilities() const
            Cantor::Backend::VariableManagement;
 }
 
-bool Python2Backend::requirementsFullfilled() const
-{
-    QFileInfo info(Python2Settings::self()->path().toLocalFile());
-    return info.isExecutable();
-}
-
 QWidget* Python2Backend::settingsWidget(QWidget* parent) const
 {
     QWidget* widget=new QWidget(parent);
